@@ -3,7 +3,7 @@ package MaxMind::DB::Writer;
 use strict;
 use warnings;
 
-our $VERSION = '0.201001';
+our $VERSION = '0.201002';
 
 1;
 
@@ -13,13 +13,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 MaxMind::DB::Writer - Create MaxMind DB database files
 
 =head1 VERSION
 
-version 0.201001
+version 0.201002
 
 =head1 SYNOPSIS
 
@@ -80,6 +82,8 @@ L<https://github.com/maxmind/MaxMind-DB-Writer-perl/issues>.
 We welcome patches as pull requests against our GitHub repository at
 L<https://github.com/maxmind/MaxMind-DB-Writer-perl>.
 
+Bugs may be submitted through L<https://github.com/maxmind/MaxMind-DB-Writer-perl/issues>.
+
 =head1 AUTHORS
 
 =over 4
@@ -104,7 +108,7 @@ Mark Fowler <mfowler@maxmind.com>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Florian Ragwitz Jan Bieron
+=for stopwords Florian Ragwitz Jan Bieron tjmather
 
 =over 4
 
@@ -116,6 +120,10 @@ Florian Ragwitz <rafl@debian.org>
 
 Jan Bieron <jbieron+github@gmail.com>
 
+=item *
+
+tjmather <tjmather@maxmind.com>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
