@@ -5,7 +5,7 @@ use warnings;
 use namespace::autoclean;
 use autodie;
 
-our $VERSION = '0.201001';
+our $VERSION = '0.201002';
 
 use IO::Handle;
 use Math::Int64 0.51;
@@ -442,7 +442,8 @@ sub new_from_frozen_tree {
         record_size           => { isa => $RecordSizeType, optional => 1 },
         );
 
-    open my $fh, '<:raw', $filename;
+    ## no critic (InputOutput::RequireBriefOpen)
+    open my $fh, '<:raw', $filename or die $!;
     my $packed_params_size;
     unless ( read( $fh, $packed_params_size, 4 ) == 4 ) {
         die "Could not read 4 bytes from $filename: $!";
@@ -453,6 +454,8 @@ sub new_from_frozen_tree {
     unless ( read( $fh, $frozen_params, $params_size ) == $params_size ) {
         die "Could not read $params_size bytes from $filename: $!";
     }
+    close $fh or die $!;
+
     my $params = decode_sereal($frozen_params);
 
     $params->{database_type} = $database_type if defined $database_type;
@@ -508,13 +511,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 MaxMind::DB::Writer::Tree - Tree representing a MaxMind DB database in memory - then write it to a file
 
 =head1 VERSION
 
-version 0.201001
+version 0.201002
 
 =head1 SYNOPSIS
 
@@ -1060,6 +1065,10 @@ The valid types are:
 
 =back
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<https://github.com/maxmind/MaxMind-DB-Writer-perl/issues>.
+
 =head1 AUTHORS
 
 =over 4
